@@ -5,7 +5,10 @@ use ndarray::RcArray;
 use ndarray::{arr0, rcarr1, rcarr2};
 use ndarray::{
     OwnedArray,
-    Ix,
+    Ix, Ixs,
+    AsArray,
+    NdFloat,
+    aview0,
 };
 
 use std::fmt;
@@ -119,20 +122,77 @@ fn assert_approx_eq<F: fmt::Debug + Float>(f: F, g: F, tol: F) -> bool {
     true
 }
 
+fn reference_dot<'a,A, V1, V2>(a: V1, b: V2) -> A
+    where A: NdFloat,
+          V1: AsArray<'a, A>,
+          V2: AsArray<'a, A>,
+{
+    let a = a.into();
+    let b = b.into();
+    a.iter().zip(b.iter()).fold(A::zero(), |acc, (&x, &y)| {
+        acc + x * y
+    })
+}
+
 #[test]
 fn dot_product() {
     let a = OwnedArray::range(0., 69., 1.);
     let b = &a * 2. - 7.;
     let dot = 197846.;
-    assert_approx_eq(a.dot(&b), dot, 1e-5);
+    assert_approx_eq(a.dot(&b), reference_dot(&a, &b), 1e-5);
+
+    // test different alignments
+    let max = 8 as Ixs;
+    for i in 1..max {
+        let a1 = a.slice(s![i..]);
+        let b1 = b.slice(s![i..]);
+        assert_approx_eq(a1.dot(&b1), reference_dot(&a1, &b1), 1e-5);
+        let a2 = a.slice(s![..-i]);
+        let b2 = b.slice(s![i..]);
+        assert_approx_eq(a2.dot(&b2), reference_dot(&a2, &b2), 1e-5);
+    }
+
+
     let a = a.map(|f| *f as f32);
     let b = b.map(|f| *f as f32);
     assert_approx_eq(a.dot(&b), dot as f32, 1e-5);
+
+    let max = 8 as Ixs;
+    for i in 1..max {
+        let a1 = a.slice(s![i..]);
+        let b1 = b.slice(s![i..]);
+        assert_approx_eq(a1.dot(&b1), reference_dot(&a1, &b1), 1e-5);
+        let a2 = a.slice(s![..-i]);
+        let b2 = b.slice(s![i..]);
+        assert_approx_eq(a2.dot(&b2), reference_dot(&a2, &b2), 1e-5);
+    }
+
     let a = a.map(|f| *f as i32);
     let b = b.map(|f| *f as i32);
     assert_eq!(a.dot(&b), dot as i32);
 }
 
+// test that we can dot product with a broadcast array
+#[test]
+fn dot_product_0() {
+    let a = OwnedArray::range(0., 69., 1.);
+    let x = 1.5;
+    let b = aview0(&x);
+    let b = b.broadcast(a.dim()).unwrap();
+    assert_approx_eq(a.dot(&b), reference_dot(&a, &b), 1e-5);
+
+    // test different alignments
+    let max = 8 as Ixs;
+    for i in 1..max {
+        let a1 = a.slice(s![i..]);
+        let b1 = b.slice(s![i..]);
+        assert_approx_eq(a1.dot(&b1), reference_dot(&a1, &b1), 1e-5);
+        let a2 = a.slice(s![..-i]);
+        let b2 = b.slice(s![i..]);
+        assert_approx_eq(a2.dot(&b2), reference_dot(&a2, &b2), 1e-5);
+    }
+}
+
 fn range_mat(m: Ix, n: Ix) -> OwnedArray<f32, (Ix, Ix)> {
     OwnedArray::linspace(0., (m * n - 1) as f32, m * n).into_shape((m, n)).unwrap()
 }
